<?php
namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\SolicitacaoService;

class SolicitacaoController extends FMCrud{
    protected $dataSourceName = 'fcm_checklistagend';
    protected $SolicitacaoService;
   
    public function __construct($crudService, $environment, SolicitacaoService $SolicitacaoService) {
        parent::__construct($crudService, $environment);
        $this->SolicitacaoService = $SolicitacaoService;
    }
    
    // Busca os tipos de requisição
    public function getRequests(DTO\Request $request, DTO\Response $response) {
        $var = $this->SolicitacaoService->getRequests();

        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
    
    // Busca os tipos de requisição
    public function getRequestTypes(DTO\Request $request, DTO\Response $response) {
        $var = $this->SolicitacaoService->getRequestTypes();

        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
    
    // Busca as informações de uma solicitação específica
    public function getRequestInfo(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        
        $var = $this->SolicitacaoService->getRequestInfo($params['nrsolicitacao']);

        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
    
    // Busca o histórico de uma solicitação
    public function getRequestHistoric(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        
        $var = $this->SolicitacaoService->getRequestHistoric($params['nrsolicitacao']);

        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
    
    // Insere um novo tipo de requisição
    public function insertRequestType(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        
        $var = $this->SolicitacaoService->insertRequestType($params['params']);

        $dtsVal = new DataSet('info',array('message' => $var));
        $response->addDataSet($dtsVal);
    }
    
    // Faz o processo de classificação da solicitação
    public function classifyRequest(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        
        $var = $this->SolicitacaoService->classifyRequest($params['params']);

        $dtsVal = new DataSet('info',array('message' => $var));
        $response->addDataSet($dtsVal);
    }
    
    // Edita o tipo de solicitação
    public function updateRequestType(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        
        $var = $this->SolicitacaoService->updateRequestType($params['params']);

        $dtsVal = new DataSet('info',array('message' => $var));
        $response->addDataSet($dtsVal);
    }
}
?>